isWeb property
bool
get
isWeb
Indicates whether the code is running in a Web environment.
Stub version → always returns false.
Implementation
static bool get isWeb => false;
Indicates whether the code is running in a Web environment.
Stub version → always returns false.
static bool get isWeb => false;